{% extends "admin/base_site.html" %}
{% load i18n staticfiles %}

{% block extrastyle %}{{ block.super }}
<link rel="stylesheet" type="text/css" href="{% static "filer/css/admin_style.css" %}" />
{% endblock %}
