
/* focal point */
#image_container { position: relative; } 
#image_container img, #image_container svg { margin: 0px; position: absolute; top: 0; left: 0;}

/* Tile pattern as background for transparent images: */
.transpTiling {
    /* light tiles */
    background-image: url(data:image/gif;base64,R0lGODlhCAAIAKECAOPj4/z8/P///////yH5BAEKAAIALAAAAAAIAAgAAAINhBEZh8q6DoTPSWvoKQA7);
    outline: 1px solid #E3E3E3;
}
.transpTiling:hover {
    /* dark tiles */
    background-image: url(data:image/gif;base64,R0lGODlhCAAIAKECAEFBQXR0dP///////yH5BAEKAAIALAAAAAAIAAgAAAINhBEZh8q6DoTPSWvoKQA7);
}

/* the directory listing */
table thead th.thumbHeader {
	width: 52px;
}
#fileUploadFakeLink {
	position: relative;
	
}
#fileInputUploaderContainer {
	position: absolute;
	top:0;
	left: -8px;
}
#fileInputUploader {
}
.fileUploadQueueItem .fileUploadProgress .fileUploadProgressBar {
	background-color: black;
}
.loadingThumb {
	width: 32px;
	height: 32px;
	background-image: url(../img/loading_animation.gif);
	background-repeat:no-repeat;
	
}

#content-top-bar {
	margin-bottom: 20px;
}

#content-top-bar .object-tools {
	text-align: right;
	margin-top: -32px;
}
#content-top-bar .changelink {
	color: #029eee !important;
	font-weight: normal !important;
	padding-left: 15px !important;
	background: url(../img/icon_changelink.gif) 0 center no-repeat !important;
	background-color: transparent !important;
	box-shadow: none !important;
	border: 0 !important;
}
#content-top-bar .object-tools li {
	display: inline-block !important;
	float: none !important;
}
.filebrowser #changelist {
	overflow: hidden;
}
.filebrowser #changelist .change {
	text-align: right;
}
.filebrowser #changelist .change a {
	display: block;
	float: right;
}
.filebrowser #changelist .moveto {
	text-align: right;
	min-width: 180px
}

.filebrowser #changelist .moveto a {
	display: inline-block;
	margin-right: 10px;
}
.filebrowser #changelist .moveto button {
	float: right;
}
#changelist-wrapper {
	float: left;
	width: 80%;
	margin-right: 2%;
}
.clipboard {
	width: 18% !important;
    float: left;
	margin-top: -1px !important;
	border: 1px solid #ddd !important;
	box-sizing: border-box;
	overflow-x: auto;
}
.clipboard form {
	padding-top: 0 !important;
}
.clipboard tr td.thumbnail {
	width: 40px;
}
.clipboard table {
	margin: 0;
	border: 0 !important;
}
.clipboard table td {
	border-right: 0 !important;
	border-color: #ddd;
}
.clipboard table th {
	padding-top: 1px !important;
	padding-bottom: 1px !important;
}
.clipboard table tfoot td {
	border-bottom: 0 !important;
}
.clipboard .deletelink {
	padding: 4px 10px;
	background: #e1e1e1 url(../img/button-bg.gif) bottom left repeat-x;
    border: 1px solid #999;
}
a.insertlinkButton {
	padding: 4px;
	padding-left: 28px;
	background-image: url(../img/select_item.gif);
	background-repeat: no-repeat;
}
a.insertlinkButton:hover {
	background-image: url(../img/select_item-hover.gif);
}

h1.folder_header {
	background-image: url(../img/nav-bg.gif);
	background-repeat: repeat-x;
	background-position: bottom;
	margin-bottom: 0;
}
a.small_folder_link {
	display: block;
	height: 36px;
	background-repeat: no-repeat;
	padding-left: 36px;
	padding-right: 4px;
	background-image: url(../icons/plainfolder_32x32.png);
	line-height: 36px;
	float: right;
}
#toolbartable {
	overflow-x: auto;
}
#toolbartable td,
#toolbartable th {
	border-right: solid 1px #ddd;
}

#toolbartable + .paginator {
	border-right: solid 1px #ddd;
}
