# -*- coding: utf-8 -*-

from filer.models.clipboardmodels import *  # flake8: noqa
from filer.models.filemodels import *  # flake8: noqa
from filer.models.foldermodels import *  # flake8: noqa
from filer.models.imagemodels import *  # flake8: noqa
from filer.models.virtualitems import *  # flake8: noqa
